@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2018 Peijun Ma
+# Copyright (c) 2018-2021 Peijun Ma
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -30,5 +30,5 @@
 from .option_ import NONE, Option, Some, maybe
 from .result import Err, Ok, Result
 
-__version__ = '0.2.3'
-__all__ = ['NONE', 'Option', 'Some', 'maybe', 'Result', 'Ok', 'Err']
+__version__ = '1.0.2'
+__all__ = ['NONE', 'Option', 'Some', 'maybe', 'Result', 'Ok', 'Err', '__version__']
